# CHANGELOG

| Version               | Changes              | Additional Notes         |
|-----------------------|----------------------|--------------------------|
| PyPI Name Reservation | Reserve name on PyPI | Not a proper release yet |